<?php

//Used to set the width of images and content. Should be equal to the width the theme
//is designed for, generally via the style.css stylesheet.
if ( ! isset( $content_width ) ) $content_width = 1100;

function jazzy_setup() {
	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();
		
	load_theme_textdomain('jazzy');
	
	//Adding Theme Support
	add_theme_support( 'title-tag' );
	
	//Enabling Support for Post Thumbnails
	add_theme_support( 'post-thumbnails' ); 
	
	//Post Formats
	add_theme_support( 'post-formats', array( 'aside', 'gallery', 'jazzy' ) );
	
	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );
	
		register_nav_menus( array(
		'primary'   => __( 'Top primary menu', 'jazzy' ),
		'secondary' => __( 'Secondary in footer', 'jazzy' ),
		'tertiary'  => __( 'Tertiary for logged in users', 'jazzy' ),
	) );

	//Adding Theme Logo
	//https://codex.wordpress.org/Theme_Logo
	add_theme_support( 'custom-logo', array(
		'height'      => 180,
		'width'       => 180,
		'flex-height' => true,
		//'header-text' => array( 'site-title', 'site-description' ),
	) );

	//Custom header is an image that is chosen as the representative image in the theme top header section.
	//http://codex.wordpress.org/Custom_Headers
	$headerdefaults = array(
		'default-image'          => get_template_directory_uri() . '/images/headers/blueprints.jpg',
		'width'                  => 940,
		'height'                 => 198,
		'flex-height'            => false,
		'flex-width'             => false,
		'uploads'                => true,
		'random-default'         => false,
		'header-text'            => true,  //Header Text Modification
		'default-text-color'     => '#000000', //Header Text Color
		'wp-head-callback'       => '',
		'admin-head-callback'    => '',
		'admin-preview-callback' => '',
		);
	add_theme_support( 'custom-header', $headerdefaults );	
	
	set_post_thumbnail_size( $headerdefaults['width'], $headerdefaults['height'], true );
	
	// Default custom headers packaged with the theme. %s is a placeholder for the theme template directory URI.
	register_default_headers( array(
		'blueflower' => array(
			'url' => '%s/images/headers/blueflower.jpg',
			'thumbnail_url' => '%s/images/headers/blueflower-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Blue Flower', 'jazzy' )
		),
		'flower' => array(
			'url' => '%s/images/headers/flower.jpg',
			'thumbnail_url' => '%s/images/headers/flower-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Flower', 'jazzy' )
		),
		'raindrops' => array(
			'url' => '%s/images/headers/raindrops.jpg',
			'thumbnail_url' => '%s/images/headers/raindrops-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Rain Drops', 'jazzy' )
		),
		'pond' => array(
			'url' => '%s/images/headers/pond.jpg',
			'thumbnail_url' => '%s/images/headers/ponds-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Pond', 'jazzy' )
		),
		'bahamasresort' => array(
			'url' => '%s/images/headers/bahamasresort.jpg',
			'thumbnail_url' => '%s/images/headers/bahamasresort-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Bahamas Resort', 'jazzy' )
		),
		'atlanticsunset' => array(
			'url' => '%s/images/headers/atlanticsunset.jpg',
			'thumbnail_url' => '%s/images/headers/atlanticsunset-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Atlantic Sunset', 'jazzy' )
		),
		'pond' => array(
			'url' => '%s/images/headers/pond.jpg',
			'thumbnail_url' => '%s/images/headers/pond-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Pond', 'jazzy' )
		)
	) );

	//Custom Backgrounds is a theme feature that provides for customization of the background color and image. 
	//http://codex.wordpress.org/Custom_Backgrounds
	$backgrounddefaults = array(
		'default-color'          => '#f5f5f5', //Background Color
		'default-image'          => '',
		'default-repeat'         => '',
		'default-position-x'     => '',
		'default-attachment'     => '',
		'wp-head-callback'       => '_custom_background_cb',
		'admin-head-callback'    => '',
		'admin-preview-callback' => ''
		);
	add_theme_support( 'custom-background', $backgrounddefaults );
}

add_action( 'after_setup_theme', 'jazzy_setup' );
/****************************************
 * Enqueue scripts and styles	     
 ****************************************/

function jazzy_enqueue_style() { 
		// Load our main stylesheet.
	    wp_enqueue_style( 'jazzy-style', get_stylesheet_uri() );
		wp_enqueue_style( 'jazzy-menu', esc_url( get_template_directory_uri() ) . '/css/menu.css', false );
		wp_enqueue_style( 'jazzy-advanced', esc_url( get_template_directory_uri() ) . '/css/advanced.css', false );
	}
	
function jazzy_enqueue_script() {
	/*
	 * We add some JavaScript to pages with the comment form
	 * to support sites with threaded comments (when in use).
	 */
	if ( is_singular() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );
		
	//wp_enqueue_script( 'jquery');
	wp_enqueue_script( 'jquery-ui-core');
	wp_enqueue_script( 'jquery-effects-core');
	wp_enqueue_script( 'jazzy-search', esc_url( get_template_directory_uri() ) . '/js/search.js', false );
}

add_action( 'wp_enqueue_scripts', 'jazzy_enqueue_style' );
add_action( 'wp_enqueue_scripts', 'jazzy_enqueue_script' );

/****************************************
 * Includes	     
 ****************************************/
require get_template_directory() . '/inc/customizer.php';

/****************************************
 * WordPress Title	     
 ****************************************/

function jazzy_wp_title( $title )
{
  	if( empty( $title ) && ( is_home() || is_front_page() ) ) {
    	return ( bloginfo('name')  );
  	} else {
	  	return ( bloginfo('name') . ' | ' . get_the_title() ); 
  	}
  	return $title;
}
add_filter( 'wp_title', 'jazzy_wp_title' );

/****************************************
 * WordPress Search	     
 ****************************************/
 if ( ! function_exists( 'jazzy_postinfo' ) ) :

function jazzy_postinfo() {	
	
	echo '<p>';
	// Translators: 1 is the post author, 2 is the post date.
 	printf( __( 'Written by %1$s on %2$s', 'jazzy' ), get_the_author(),
 	get_the_date() );
	echo '</p>';

}
endif;

/****************************************
 * WordPress Comments    
 ****************************************/

if ( ! function_exists( 'jazzy_comment' ) ) {
	function jazzy_comment( $comment, $args, $depth ) {
		
		switch ( $comment->comment_type ) {
		case '' :
			
			echo '<li '; 
			comment_class(); 
			echo ' id="li-comment-';
			comment_ID();
			echo '">';
           
			echo '<div class="comment-author vcard">';
			echo get_avatar( $comment, 40 ); 
			printf( __( '%s <span class="says">says:</span>', 'jazzy' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) );
			echo '</div>';
			if ( $comment->comment_approved == '0' ) { 
				echo '<em>'; esc_html_e( 'Your comment is awaiting moderation.','jazzy'); 
				echo '</em>';
				echo '<br />';
			}
			
			echo '<div class="comment-meta commentmetadata"><a href="' . esc_url( get_comment_link( $comment->comment_ID ) ) . '">';
			printf( __( '%1$s at %2$s', 'jazzy' ), get_comment_date(),  get_comment_time() ); 
			echo '</a>';
			edit_comment_link( __( '(Edit)', 'jazzy' ), ' ' );
			
			echo '</div>';
		
			echo '<div class="comment-body">';
			comment_text(); 
			echo '</div>';
		
			echo '<div class="reply">';
			comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); 
			echo '</div>';
			
			break;
			
		case 'pingback'  :
		case 'trackback' :

			echo '<li class="post pingback">';
			echo '<p>'; 
			esc_html_e( 'Pingback:','jazzy' );
			comment_author_link();
			edit_comment_link( __('(Edit)', 'jazzy'), ' ' ); 
			echo '</p>';
	
		break;
		}
	}
}

/****************************************
 * WordPress Single Post   
 ****************************************/
if ( ! function_exists( 'jazzy_loop' ) ) :
	function jazzy_loop() {	
 		echo '<h3>';
		the_title();
		echo '</h3>';
		echo '<p>';
		// Translators: 1 is the post author, 2 is the post date.
 		printf( __( 'Written by %1$s on %2$s', 'jazzy' ), get_the_author(),
 		get_the_date() );
		echo '</p>';

		while ( have_posts() ) {
			the_post();	
			if ( is_archive() || is_search() ) {
				the_excerpt(); 
			} else { 
				the_content( __( '<span class="meta-nav-r">Continue reading </span>','jazzy') ); 
				wp_link_pages( array( 'before' => '<div class="page-link">' . __( 'Pages:','jazzy'), 'after' => '</div>' ) ); 
			} 
		comments_template( '', true );
	}
}
endif;
/****************************************
 * WordPress Sidebar  
 ****************************************/

function jazzy_widgets_init() {
	//Primary sidebar.
	register_sidebar( array(
		'name' => __( 'Primary Widget', 'jazzy' ),
		'id' => 'primary-widget-area',
		'description' => __( 'Add widgets here to appear in your sidebar.', 'jazzy' ),
	) ); 
 	//Second sidebar
 	register_sidebar( array(
		'name' => __( 'Secondary Widget', 'jazzy' ),
		'id' => 'secondary-widget-area',
		'description' => __( 'Optional secondary widget that displays below the primary widget in sidebar.', 'jazzy' ),
	) );
}
add_action( 'widgets_init', 'jazzy_widgets_init' );

?>